@@ -22,12 +22,7 @@ importSAQN <- function(site = "gla4", year = 2009, data_type = "hourly",
     # add meta data?
     if (meta) {
       
-      meta_data <- importMeta(source = "saqn")
-      
-      meta_data <- distinct(meta_data, site, .keep_all = TRUE) %>% 
-        select(site, code, latitude, longitude, site_type)
-      # suppress warnings about factors
-      aq_data <- left_join(aq_data, meta_data, by = c("code", "site"))
+      aq_data <- add_meta(source = "saqn", aq_data)
       
     }
     
