@@ -24,12 +24,7 @@ importWAQN <- function(site = "card", year = 2018, data_type = "hourly",
     # add meta data?
     if (meta) {
       
-      meta_data <- importMeta(source = "waqn")
-      
-      meta_data <- distinct(meta_data, site, .keep_all = TRUE) %>% 
-        select(site, code, latitude, longitude, site_type)
-      # suppress warnings about factors
-      aq_data <- left_join(aq_data, meta_data, by = c("code", "site"))
+      aq_data <- add_meta(source = "waqn", aq_data)
       
     }
     
