@@ -381,12 +381,10 @@ percentileRose <- function(mydata, pollutant = "nox", wd = "wd", type = "default
       ## calculate percentiles
       
       percentiles <- group_by(mydata, wd) %>%
-        do(data.frame(V1 = quantile(.[[pollutant]], probs = percentile / 100, na.rm = TRUE)))
-
-      names(percentiles)[names(percentiles) == "V1"] <- pollutant
-  
-      percentiles$percentile <- rep(percentile, nrow(percentiles) / length(percentile))
-     # percentiles$percentile <- percentile
+        summarise({{ pollutant }} := quantile(.data[[pollutant]], 
+                                              probs = percentile / 100, 
+                                              na.rm = TRUE)) %>% 
+        mutate(percentile = percentile)
     }
 
     if (tolower(method) == "cpf") {
